@@ -22,19 +22,13 @@ import (
 	"os"
 	"regexp"
 	"strings"
-	"time"
 
-	monitoringv1 "github.com/coreos/prometheus-operator/pkg/apis/monitoring/v1"
-	yaml "github.com/ghodss/yaml"
 	"github.com/hashicorp/go-version"
 	"github.com/pkg/errors"
 	v1 "k8s.io/api/core/v1"
-	extensionsobj "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1beta1"
 	apierrors "k8s.io/apimachinery/pkg/api/errors"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
-	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/util/validation"
-	"k8s.io/apimachinery/pkg/util/wait"
 	"k8s.io/client-go/discovery"
 	clientv1 "k8s.io/client-go/kubernetes/typed/core/v1"
 	"k8s.io/client-go/rest"
@@ -46,30 +40,6 @@ const KubeConfigEnv = "KUBECONFIG"
 
 var invalidDNS1123Characters = regexp.MustCompile("[^-a-z0-9]+")
 
-// CustomResourceDefinitionTypeMeta set the default kind/apiversion of CRD
-var CustomResourceDefinitionTypeMeta metav1.TypeMeta = metav1.TypeMeta{
-	Kind:       "CustomResourceDefinition",
-	APIVersion: "apiextensions.k8s.io/v1beta1",
-}
-
-// WaitForCRDReady waits for a custom resource definition to be available for use.
-func WaitForCRDReady(listFunc func(opts metav1.ListOptions) (runtime.Object, error)) error {
-	err := wait.Poll(3*time.Second, 10*time.Minute, func() (bool, error) {
-		_, err := listFunc(metav1.ListOptions{})
-		if err != nil {
-			if se, ok := err.(*apierrors.StatusError); ok {
-				if se.Status().Code == http.StatusNotFound {
-					return false, nil
-				}
-			}
-			return false, errors.Wrap(err, "failed to list CRD")
-		}
-		return true, nil
-	})
-
-	return errors.Wrap(err, fmt.Sprintf("timed out waiting for Custom Resource"))
-}
-
 // PodRunningAndReady returns whether a pod is running and each container has
 // passed it's ready state.
 func PodRunningAndReady(pod v1.Pod) (bool, error) {
@@ -135,21 +105,21 @@ func IsResourceNotFoundError(err error) bool {
 	return false
 }
 
-func CreateOrUpdateService(sclient clientv1.ServiceInterface, svc *v1.Service) error {
-	service, err := sclient.Get(context.TODO(), svc.Name, metav1.GetOptions{})
+func CreateOrUpdateService(ctx context.Context, sclient clientv1.ServiceInterface, svc *v1.Service) error {
+	service, err := sclient.Get(ctx, svc.Name, metav1.GetOptions{})
 	if err != nil && !apierrors.IsNotFound(err) {
 		return errors.Wrap(err, "retrieving service object failed")
 	}
 
 	if apierrors.IsNotFound(err) {
-		_, err = sclient.Create(context.TODO(), svc, metav1.CreateOptions{})
+		_, err = sclient.Create(ctx, svc, metav1.CreateOptions{})
 		if err != nil {
 			return errors.Wrap(err, "creating service object failed")
 		}
 	} else {
 		svc.ResourceVersion = service.ResourceVersion
 		svc.SetOwnerReferences(mergeOwnerReferences(service.GetOwnerReferences(), svc.GetOwnerReferences()))
-		_, err := sclient.Update(context.TODO(), svc, metav1.UpdateOptions{})
+		_, err := sclient.Update(ctx, svc, metav1.UpdateOptions{})
 		if err != nil && !apierrors.IsNotFound(err) {
 			return errors.Wrap(err, "updating service object failed")
 		}
@@ -158,20 +128,20 @@ func CreateOrUpdateService(sclient clientv1.ServiceInterface, svc *v1.Service) e
 	return nil
 }
 
-func CreateOrUpdateEndpoints(eclient clientv1.EndpointsInterface, eps *v1.Endpoints) error {
-	endpoints, err := eclient.Get(context.TODO(), eps.Name, metav1.GetOptions{})
+func CreateOrUpdateEndpoints(ctx context.Context, eclient clientv1.EndpointsInterface, eps *v1.Endpoints) error {
+	endpoints, err := eclient.Get(ctx, eps.Name, metav1.GetOptions{})
 	if err != nil && !apierrors.IsNotFound(err) {
 		return errors.Wrap(err, "retrieving existing kubelet endpoints object failed")
 	}
 
 	if apierrors.IsNotFound(err) {
-		_, err = eclient.Create(context.TODO(), eps, metav1.CreateOptions{})
+		_, err = eclient.Create(ctx, eps, metav1.CreateOptions{})
 		if err != nil {
 			return errors.Wrap(err, "creating kubelet endpoints object failed")
 		}
 	} else {
 		eps.ResourceVersion = endpoints.ResourceVersion
-		_, err = eclient.Update(context.TODO(), eps, metav1.UpdateOptions{})
+		_, err = eclient.Update(ctx, eps, metav1.UpdateOptions{})
 		if err != nil {
 			return errors.Wrap(err, "updating kubelet endpoints object failed")
 		}
@@ -195,23 +165,6 @@ func GetMinorVersion(dclient discovery.DiscoveryInterface) (int, error) {
 	return ver.Segments()[1], nil
 }
 
-// NewCustomResourceDefinition creates a CustomResourceDefinition by unmarshalling
-// the associated yaml asset
-func NewCustomResourceDefinition(crdKind monitoringv1.CrdKind, group string, labels map[string]string, validation bool) *extensionsobj.CustomResourceDefinition {
-	crdName := strings.ToLower(crdKind.Plural)
-	assetPath := "example/prometheus-operator-crd/" + group + "_" + crdName + ".yaml"
-	data := monitoringv1.MustAsset(assetPath)
-	crd := &extensionsobj.CustomResourceDefinition{}
-	err := yaml.Unmarshal(data, crd)
-	if err != nil {
-		panic("unable to unmarshal crd asset for " + assetPath + ": " + err.Error())
-	}
-	crd.ObjectMeta.Name = crd.Spec.Names.Plural + "." + group
-	crd.ObjectMeta.Labels = labels
-	crd.Spec.Group = group
-	return crd
-}
-
 // SanitizeVolumeName ensures that the given volume name is a valid DNS-1123 label
 // accepted by Kubernetes.
 func SanitizeVolumeName(name string) string {
